@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CALENDARSUPPORT_INCIDENCEVIEWER_H
-#define CALENDARSUPPORT_INCIDENCEVIEWER_H
+#pragma once
 
 #include "calendarsupport_export.h"
 
@@ -17,11 +16,13 @@
 
 class QAbstractItemModel;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ETMCalendar;
 }
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 /**
  * @short A viewer component for incidences in Akonadi.
  *
@@ -115,7 +116,7 @@ public Q_SLOTS:
      * @param activeDate The active date is used to calculate the actual date of
      *                   the selected incidence in case of recurring incidences.
      */
-    void setIncidence(const Akonadi::Item &incidence, const QDate &activeDate = QDate());
+    void setIncidence(const Akonadi::Item &incidence, QDate activeDate = QDate());
 
 protected:
     /**
@@ -145,4 +146,3 @@ private:
 };
 }
 
-#endif
